@@ -1,12 +1,17 @@
 import os
+from typing import Callable, Optional
+
 import numpy as np
+
 from tonic.dataset import Dataset
 
 
 class DVSGesture(Dataset):
-    """DVSGesture dataset <http://research.ibm.com/dvsgesture/>. Events have (xypt) ordering.
+    """`IBM DVS Gestures <http://research.ibm.com/dvsgesture/>`_
 
-    .. note::  This is (exceptionally) a preprocessed version of the original dataset, where recordings that originally contained multiple labels have already been cut into respective samples. Also temporal precision is reduced to ms.
+    .. note::  This is (exceptionally) a preprocessed version of the original dataset,
+               where recordings that originally contained multiple labels have already
+               been cut into respective samples. Also temporal precision is reduced to ms.
 
     ::
 
@@ -23,13 +28,12 @@ class DVSGesture(Dataset):
         train (bool): If True, uses training subset, otherwise testing subset.
         transform (callable, optional): A callable of transforms to apply to the data.
         target_transform (callable, optional): A callable of transforms to apply to the targets/labels.
+        transforms (callable, optional): A callable of transforms that is applied to both data and
+                                         labels at the same time.
     """
 
-    # Train: https://www.neuromorphic-vision.com/public/downloads/ibmGestureTrain.tar.gz
-    # Test : https://www.neuromorphic-vision.com/public/downloads/ibmGestureTest.tar.gz
-    base_url = "https://www.neuromorphic-vision.com/public/downloads/"
-    test_url = base_url + "ibmGestureTest.tar.gz"
-    train_url = base_url + "ibmGestureTrain.tar.gz"
+    test_url = "https://figshare.com/ndownloader/files/38020584"
+    train_url = "https://figshare.com/ndownloader/files/38022171"
     test_md5 = "56070e45dadaa85fff82e0fbfbc06de5"
     train_md5 = "3a8f0d4120a166bac7591f77409cb105"
     test_filename = "ibmGestureTest.tar.gz"
@@ -52,9 +56,19 @@ class DVSGesture(Dataset):
     dtype = np.dtype([("x", np.int16), ("y", np.int16), ("p", bool), ("t", np.int64)])
     ordering = dtype.names
 
-    def __init__(self, save_to, train=True, transform=None, target_transform=None):
-        super(DVSGesture, self).__init__(
-            save_to, transform=transform, target_transform=target_transform
+    def __init__(
+        self,
+        save_to: str,
+        train: bool = True,
+        transform: Optional[Callable] = None,
+        target_transform: Optional[Callable] = None,
+        transforms: Optional[Callable] = None,
+    ):
+        super().__init__(
+            save_to,
+            transform=transform,
+            target_transform=target_transform,
+            transforms=transforms,
         )
         self.train = train
 
@@ -93,12 +107,15 @@ class DVSGesture(Dataset):
             events = self.transform(events)
         if self.target_transform is not None:
             target = self.target_transform(target)
+        if self.transforms is not None:
+            events, target = self.transforms(events, target)
         return events, target
 
     def __len__(self):
         return len(self.data)
 
     def _check_exists(self):
-        return self._is_file_present() and self._folder_contains_at_least_n_files_of_type(
-            100, ".npy"
+        return (
+            self._is_file_present()
+            and self._folder_contains_at_least_n_files_of_type(100, ".npy")
         )
