@@ -1,13 +1,16 @@
 import os
-import numpy as np
+from typing import Callable, Optional
+
 import h5py
+import numpy as np
+
 from tonic.dataset import Dataset
 from tonic.io import make_structured_array
 
 
 class HSD(Dataset):
-    """Heidelberg Spiking Dataset <https://arxiv.org/abs/1910.07407> contains the Spiking Heidelberg Dataset (SHD)
-    and the Spiking Speech Commands dataset (SSC)."""
+    """Heidelberg Spiking Dataset <https://arxiv.org/abs/1910.07407> contains the Spiking
+    Heidelberg Digits (SHD) and the Spiking Speech Commands dataset (SSC)."""
 
     base_url = "https://zenkelab.org/datasets/"
     sensor_size = (700, 1, 1)
@@ -18,10 +21,10 @@ class HSD(Dataset):
         file = h5py.File(os.path.join(self.location_on_system, self.data_filename), "r")
         # adding artificial polarity of 1 and convert to microseconds
         events = make_structured_array(
-            file["spikes/times"][index]*1e6,
+            file["spikes/times"][index] * 1e6,
             file["spikes/units"][index],
             1,
-            dtype=self.dtype
+            dtype=self.dtype,
         )
         target = file["labels"][index].astype(int)
         if self.transform is not None:
@@ -35,14 +38,14 @@ class HSD(Dataset):
         return len(file["labels"])
 
     def _check_exists(self):
-        return self._is_file_present() and self._folder_contains_at_least_n_files_of_type(
-            1, ".h5"
+        return (
+            self._is_file_present()
+            and self._folder_contains_at_least_n_files_of_type(1, ".h5")
         )
 
 
 class SHD(HSD):
-    """Spiking Heidelberg Digits. One of two Heidelberg Spiking Digits <https://arxiv.org/abs/1910.07407>.
-    Events have (txp) ordering.
+    """`Spiking Heidelberg Digits <https://zenkelab.org/resources/spiking-heidelberg-datasets-shd/>`_
     ::
 
         @article{cramer2020heidelberg,
@@ -69,9 +72,17 @@ class SHD(HSD):
     train_md5 = "f3252aeb598ac776c1b526422d90eecb"
     folder_name = ""
 
-    def __init__(self, save_to, train=True, transform=None, target_transform=None):
-        super(HSD, self).__init__(
-            save_to, transform=transform, target_transform=target_transform
+    def __init__(
+        self,
+        save_to: str,
+        train: bool = True,
+        transform: Optional[Callable] = None,
+        target_transform: Optional[Callable] = None,
+    ):
+        super().__init__(
+            save_to,
+            transform=transform,
+            target_transform=target_transform,
         )
 
         if train:
@@ -92,8 +103,7 @@ class SHD(HSD):
 
 
 class SSC(HSD):
-    """Spiking Speech Commands dataset. One of two Heidelberg Spiking Datasets <https://arxiv.org/abs/1910.07407>.
-    Events have (txp) ordering.
+    """`Spiking Speech Commands <https://zenkelab.org/resources/spiking-heidelberg-datasets-shd/>`_
     ::
 
         @article{cramer2020heidelberg,
@@ -122,9 +132,14 @@ class SSC(HSD):
     valid_md5 = "b4eee3516a4a90dd0c71a6ac23a8ae43"
     folder_name = ""
 
-    def __init__(self, save_to, split="train", transform=None, target_transform=None):
-        save_to = os.path.join(save_to, self.__class__.__name__)
-        super(HSD, self).__init__(
+    def __init__(
+        self,
+        save_to: str,
+        split: str = "train",
+        transform: Optional[Callable] = None,
+        target_transform: Optional[Callable] = None,
+    ):
+        super().__init__(
             save_to, transform=transform, target_transform=target_transform
         )
 
