@@ -1,13 +1,16 @@
 import os
+from typing import Callable, Optional
+
 import numpy as np
 
-from tonic.io import read_mnist_file
 from tonic.dataset import Dataset
-from tonic.download_utils import extract_archive
+from tonic.io import read_mnist_file
 
 
 class NCALTECH101(Dataset):
-    """N-CALTECH101 dataset <https://www.garrickorchard.com/datasets/n-caltech101>. Events have (xytp) ordering.
+    """`N-CALTECH101 <https://www.garrickorchard.com/datasets/n-caltech101>`_
+
+    Events have (xytp) ordering.
     ::
 
         @article{orchard2015converting,
@@ -24,9 +27,11 @@ class NCALTECH101(Dataset):
         save_to (string): Location to save files to on disk.
         transform (callable, optional): A callable of transforms to apply to the data.
         target_transform (callable, optional): A callable of transforms to apply to the targets/labels.
+        transforms (callable, optional): A callable of transforms that is applied to both data and
+                                         labels at the same time.
     """
 
-    url = "https://data.mendeley.com/public-files/datasets/cy6cvx3ryv/files/36b5c52a-b49d-4853-addb-a836a8883e49/file_downloaded" 
+    url = "https://data.mendeley.com/public-files/datasets/cy6cvx3ryv/files/36b5c52a-b49d-4853-addb-a836a8883e49/file_downloaded"
     filename = "N-Caltech101-archive.zip"
     file_md5 = "66201824eabb0239c7ab992480b50ba3"
     data_filename = "Caltech101.zip"
@@ -36,9 +41,18 @@ class NCALTECH101(Dataset):
     dtype = np.dtype([("x", int), ("y", int), ("t", int), ("p", int)])
     ordering = dtype.names
 
-    def __init__(self, save_to, transform=None, target_transform=None):
-        super(NCALTECH101, self).__init__(
-            save_to, transform=transform, target_transform=target_transform
+    def __init__(
+        self,
+        save_to: str,
+        transform: Optional[Callable] = None,
+        target_transform: Optional[Callable] = None,
+        transforms: Optional[Callable] = None,
+    ):
+        super().__init__(
+            save_to,
+            transform=transform,
+            target_transform=target_transform,
+            transforms=transforms,
         )
 
         if not self._check_exists():
@@ -66,12 +80,15 @@ class NCALTECH101(Dataset):
             events = self.transform(events)
         if self.target_transform is not None:
             target = self.target_transform(target)
+        if self.transforms is not None:
+            events, target = self.transforms(events, target)
         return events, target
 
     def __len__(self):
         return len(self.data)
 
     def _check_exists(self):
-        return self._is_file_present() and self._folder_contains_at_least_n_files_of_type(
-            8709, ".bin"
+        return (
+            self._is_file_present()
+            and self._folder_contains_at_least_n_files_of_type(8709, ".bin")
         )
